// This file is part of the scetoexe module for Scilab
//
// Samuel GOUGEON - 2018

function [output, OK, exitcode] = scetoexe(scriptSCE, outDir, devenvProg, cleanTMPdir)

    // Initializations
    // ---------------
    output = []
    OK = %f
    exitcode = []
    filebase = fileparts(scriptSCE, "fname")
    tmpdir = TMPDIR + "\" + filebase
    if isdir(tmpdir) then
        rmdir(tmpdir, "s")
    end

    // Checking input arguments
    // ------------------------
    if getos()~="Windows"
        warning("scetoexe() is for Windows only.")
        return
    end
    if ~isfile(scriptSCE) then
        warning(msprintf("scetoexe: The file ""%s"" does not exist.", scriptSCE))
        return
    end
    if ~isdef("outDir","l") | outDir==""
        outDir = pathconvert(fileparts(scriptSCE, "path"))
    elseif or(outDir==["." ".."])
        outDir =  outDir + "\"
    else
        outDir = pathconvert(outDir)
    end
    if ~isdir(outDir) then
        msg = "scetoexe: The directory ""%s"" does not exist.\nPlease create it before calling scetoexe().\n"
        warning(msprintf(msg, scriptSCE))
        return
    end
    if  ~isdef("devenvProg","l") | devenvProg=="devenv" then
        devenvProg = "devenv"
    else
        OK = isfile(devenvProg);
        if ~OK
            msg = "The devenv program ""%s"" does not exist. Please check the given path.\n"
            warning(msprintf(msg, devenvProg));
            return
        end
    end

    // Processing
    // ----------
    mkdir(tmpdir)
    bOK = scetoexe_generate(scriptSCE, tmpdir);
    sleep(1000)  // Letting all files being copied
    if ~isfile(pathconvert(tmpdir) + filebase + ".sln") then
        msg = "scetoexe: No file ""%s"" expected from scetoexe_generate() has been found in ""%s"".\n"
        warning(msprintf(msg, filebase+".sln", tmpdir))
        return
    end
    if getscilabmode()~="NWNI" then
        pbid = progressionbar("Please wait while building the .exe...");
    end
    mprintf("Please wait while building the .exe... ")
    [output, OK, exitcode] = scetoexe_buildsln(tmpdir+"\"+filebase+".sln", %T, devenvProg);
    // %t = Release  %F = Debug
    if getscilabmode()~="NWNI" then
        close(pbid)
    end
    mprintf("Done\n")

    // Moving the .exe to its final directory
    // --------------------------------------
    tmp = TMPDIR + "\" + filebase + "\" + filebase + ".exe"
    if isfile(tmp) then
        movefile(tmp, outDir+filebase+".exe")
    else
        warning(msprintf("scetoexe(): No %s.exe file has been generated.", filebase))
    end

    // Removal of the compilation directory:
    // ------------------------------------
    if isdir(tmpdir) & (~isdef("cleanTMPdir", "l") | cleanTMPdir) then
        rmdir(tmpdir, "s")
    end
endfunction
