// Allan CORNET - 2010
// Internal function called by scetoexe()

function bOK = scetoexe_generate(filenameSCE, directoryDest)

    function bOK = update_FILE_EMBEDDED(file_embedded, filenameSCE)
        bOK = %F;
        if isfile(file_embedded) then
            [path, fname, extension] = fileparts(filenameSCE);
            filenamecleaned = fname + extension;
            txt = mgetl(file_embedded);
            txt = [txt
                    ""
                    "const char FILENAME[] = """ + filenamecleaned + """;"
                    ""];
            bOK = mputl(txt, file_embedded);
        end
    endfunction

    function bOK = copyTemplate(directoryDest)
        bOK = %F;
        if isdir(directoryDest) then
            FILESTOCOPY = [
                "scilabWrap.h"
                "scilabWrap.cpp"
                "helpers_utils.h"
                "helpers_utils.cpp"
                "main.c"
                "getScilabPath.hxx"
                "getScilabPath.cpp"
                "FileExists.h"
                "FileExists.c"
                ];
            bCopy = %T;
            for i = 1: size(FILESTOCOPY, "*")
                bCopy = bCopy & copyfile(scetoexe_getRootPath() + "\src\c\" + ..
                        FILESTOCOPY(i), directoryDest + "\" + FILESTOCOPY(i));
            end
            bOK = bCopy;
        end
    endfunction

    function bOK = generateVSsolution(filenameSCE, directoryDest)
        bOK = %F;
        inpath = scetoexe_getRootPath() + "\src\c\";
        VS_NAME = fileparts(filenameSCE, "fname");
        sln = mgetl(inpath+ "scetoexe.sln");
        sln = strsubst(sln, "scetoexe", VS_NAME);
        vcxproj = mgetl(inpath + "scetoexe.vcxproj");
        vcxproj = strsubst(vcxproj, "scetoexe", VS_NAME);
        bOK = mputl(sln, directoryDest + "\" + VS_NAME + ".sln") & ..
              mputl(vcxproj, directoryDest + "\" + VS_NAME + ".vcxproj") &..
              copyfile(inpath+"scetoexe.vcxproj.filters", ..
               directoryDest + "\" + VS_NAME + ".vcxproj.filters");
    endfunction


    bOK = %F;
    if isfile(filenameSCE) & isdir(directoryDest) then
        fullfileDest = directoryDest + filesep() + "FILE_EMBEDDED.h";
        if (scetoexe_reswarp(filenameSCE, fullfileDest)) then
            if (update_FILE_EMBEDDED(fullfileDest, filenameSCE)) then
                bOK = copyTemplate(directoryDest) & generateVSsolution(filenameSCE, directoryDest);
            end
        end
    end
endfunction

// -------------------------------------------------------------------
// Allan CORNET - 2010

function bOK = scetoexe_reswarp(filenameSrc, filenameDest, options)
    // convert a file to a resource array header.</refpurpose>
    FS = filesep();
    bOK = %F;
    [lhs, rhs] = argn(0);
    if rhs == 2 then
        options = "-r FILENAME_EMBEDDED -nc -z";
    end

    if getos() == "Windows" then
        reswarpPath = scetoexe_getRootPath() + FS + 'bin' + FS + 'reswarp.exe';
    else
        reswarpPath = 'reswarp';
    end

    commandLine = reswarpPath + " " + options + " -o """ + ..
                  filenameDest + """ """ + filenameSrc + """";
    [rep, stat] = unix_g(commandLine);
    bOK = (stat == 0);
endfunction

//> reswarp --help
// Usage: reswrap [options] [-o[a] outfile] files...
// Convert files containing images, text, or binary data into C/C++ data arrays.
//
// Options:
//  -?, --help                Print this help
//  -v, --version             Print version number
//  -h, --header              Create header file containing only declarations
//  -s, --source              Create source file containing data arrays (default)
//  -i file, --include file   Generate #include "file" in output file
//  -o file, --output file    Output to file instead of stdout
//  -oa file, --append file   Append to file instead of stdout
//  -e, --extern              Generate extern reference declarations (default for headers)
//  -S, --static              Generate static reference declarations
//  -z, --size                Output size in array declarations
//  -d, --decimal             Output as decimal
//  -x, --hex                 Output as hex (default)
//  -t, --text                Output as hexadecimal text string
//  -ta, --ascii              Output as ascii text string
//  -k, --keep-ext            Keep file extension, replacing period by underscore
//  -nk, --drop-ext           Drop extension (default)
//  -m, --msdos               Read files with MS-DOS mode
//  -b, --binary              Read files using binary mode (default)
//  -u, --unsigned            Force unsigned char even for text mode
//  -N  --no-const            Don't output const specifier in declaration
//  -C  --const               Force const specifier in declaration
//  -cc, --comments           Add comments to the output files (default)
//  -nc, --no-comments        Remove comments from the output files
//  -p name, --prefix name    Prepend name in front of names of declarations and definitions
//  -f name, --suffix name    Append name in after names of declarations and definitions
//  -n name, --namespace name Place declarations and definitions inside namespace name
//  -c cols, --columns cols   Change number of columns in output to cols
//  -r name, --resource name  Override resource name of following resource file
